LavaPainter class

A custom painter that renders Lava animations frame by frame.

This painter handles the rendering of both keyframes and diff frames, applying the appropriate transformations to display the animation correctly within the available space.

Used internally by LavaView to render the animation.

Inheritance

Constructors

LavaPainter({required LavaAsset asset, required int frameIndex})
Creates a new LavaPainter with the specified asset and frame index.

Properties

asset LavaAsset
The Lava animation asset to render.
final
frameIndex int
The current frame index to display.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Paints the current frame of the Lava animation on the canvas.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant LavaPainter oldDelegate) bool
Determines whether the painter should repaint.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited